(configure-hooks-from-config {:shadow.build/keys [build-id] :as state}
build-hooks)(enhance-warnings state
{:keys [resource-id file resource-name warnings] :as rc})adds source excerpts to warnings if line information is available
adds source excerpts to warnings if line information is available
(process-stage {:shadow.build/keys [config mode target-fn] :as state}
stage
optional?)(resources-compiled-recently {:keys [build-sources compile-start] :as state})returns a vector of resource-ids that where compiled in the last compile call
returns a vector of resource-ids that where compiled in the last compile call
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |