generic helpers for the build data structure
generic helpers for the build data structure
(add-string-lookup {:keys [sources] :as state} require-from-ns require sym)(get-deps-for-id state result rc-id)returns all deps as a set for a given id, these are unordered only a helper for caching
returns all deps as a set for a given id, these are unordered only a helper for caching
(get-source-code state
{:keys [resource-id type source-fn source file url] :as rc})this loads the source code for each source or uses the current if already loaded everything should only ever access :source from the compiler resources and never access the filesystem again (since it may have changed)
the loading is delayed until here because of the :foreign which may have a minified file that should be used for release builds
this loads the source code for each source or uses the current if already loaded everything should only ever access :source from the compiler resources and never access the filesystem again (since it may have changed) the loading is delayed until here because of the :foreign which may have a minified file that should be used for release builds
(js-names-accessed-from-cljs {:keys [build-sources] :as state})(js-names-accessed-from-cljs {:keys [js-entries] :as state} build-sources)(maybe-add-source {:keys [sources] :as state} {:keys [resource-id] :as rc})add given resource to the :sources and lookup indexes
add given resource to the :sources and lookup indexes
(overwrite-source state {:keys [ns resource-id] :as rc})adds a source to the build state, if the ns was provided previously the other is removed
adds a source to the build state, if the ns was provided previously the other is removed
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |