(do-build-commands {:keys [builds] :as config}
{:keys [action options] :as opts}
build-ids)(from-remote complete-token error-token args)the CLI script calls this with 2 extra token (uuids) that will be printed to notify the script whether or not to exit with an error code, it also causes the client to disconnect instead of us forcibly dropping the connection
the CLI script calls this with 2 extra token (uuids) that will be printed to notify the script whether or not to exit with an error code, it also causes the client to disconnect instead of us forcibly dropping the connection
(print-token token)attempts to print the given token to stdout which may be a socket if the client already closed the socket that would cause a SocketException so we ignore any errors since the client is already gone
attempts to print the given token to stdout which may be a socket if the client already closed the socket that would cause a SocketException so we ignore any errors since the client is already gone
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |