(repl-client socket args)readline client that tries to maintain a prompt. not quite smart yet.
readline client that tries to maintain a prompt. not quite smart yet.
(run project-root config server-port-file opts args fallback)attempts to connect to running server. if the connect fails calls callback
attempts to connect to running server. if the connect fails calls callback
(socket-pipe socket args)client that just pipes everything through the socket without any processing
client that just pipes everything through the socket without any processing
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |