(load-macros-and-set-ns-info state {:keys [name] :as new-ns-info})modifies the repl and analyzer state to reflect the updated ns changes done by require in the REPL
modifies the repl and analyzer state to reflect the updated ns changes done by require in the REPL
(process-input state repl-input)processes a string of forms, may read multiple forms
processes a string of forms, may read multiple forms
(process-input-stream {:keys [repl-state] :as state} input-stream)reads one form of the input stream and calls process-form
reads one form of the input stream and calls process-form
(process-read-result {:keys [repl-state] :as state}
{:keys [form source] :as read-result})(read-one repl-state
reader
{:keys [filename] :or {filename "repl-input.cljs"} :as opts})(repl-load-file* {:keys [source-paths classpath] :as state}
{:keys [file-path source]})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |