backport 1.10 tap functionality
backport 1.10 tap functionality
(add-tap key f)adds f, a fn of one argument, to the tap set. This function will be called with anything sent via tap>. This function may (briefly) block (e.g. for streams), and will never impede calls to tap>, but blocking indefinitely may cause tap values to be dropped. Remember f in order to remove-tap
adds f, a fn of one argument, to the tap set. This function will be called with anything sent via tap>. This function may (briefly) block (e.g. for streams), and will never impede calls to tap>, but blocking indefinitely may cause tap values to be dropped. Remember f in order to remove-tap
(remove-tap key)remove f from the tap set the tap set.
remove f from the tap set the tap set.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |