(get-test-namespaces)returns all the registered test namespaces and symbols use (get-test-ns-info the-sym) to get the details
returns all the registered test namespaces and symbols use (get-test-ns-info the-sym) to get the details
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |